searchData={"items":[{"type":"module","title":"UBootEnv","doc":"UBootEnv reads and writes U-Boot environment blocks\n\nIt's like the commandline tools `fw_setenv` and `fw_printenv` except in pure\nElixir. It also uses `/etc/fw_env.config` by default to figure out where the\nenvironment exists so that you need not store the configuration in two\nplaces.","ref":"UBootEnv.html"},{"type":"function","title":"UBootEnv.configuration/0","doc":"Load the U-Boot environment configuration\n\nThis is returns the default U-Boot environment configuration from\n`\"/etc/fw_env.config\"`. If you do not want this, see\n`UBootEnv.Config.from_file/1` or `UBootEnv.Config.from_string/1` for\ncreating or loading a custom configuration.","ref":"UBootEnv.html#configuration/0"},{"type":"function","title":"UBootEnv.read/0","doc":"Read the U-Boot environment into a map or key value pairs\n\nThe configuration from `\"/etc/fw_env.config\"` is used to find the location of\nthe environment block. See `read/1` for specifying a custom location.","ref":"UBootEnv.html#read/0"},{"type":"function","title":"UBootEnv.read/1","doc":"Read the U-Boot environment into a map or key value pairs","ref":"UBootEnv.html#read/1"},{"type":"function","title":"UBootEnv.write/1","doc":"Write a map of key value pairs to the U-Boot environment\n\nThe configuration from `\"/etc/fw_env.config\"` is used to find the location of\nthe environment block. See `write/2` for specifying a custom location.","ref":"UBootEnv.html#write/1"},{"type":"function","title":"UBootEnv.write/2","doc":"Write a map of key-value pairs to the U-Boot environment","ref":"UBootEnv.html#write/2"},{"type":"module","title":"UBootEnv.Config","doc":"Utilities for reading the U-Boot's `fw_env.config` file.","ref":"UBootEnv.Config.html"},{"type":"function","title":"UBootEnv.Config.first/1","doc":"Return the first location","ref":"UBootEnv.Config.html#first/1"},{"type":"function","title":"UBootEnv.Config.format/1","doc":"Return whether this is a redundant environment","ref":"UBootEnv.Config.html#format/1"},{"type":"function","title":"UBootEnv.Config.from_file/1","doc":"Create a UBootEnv.Config from a file (`/etc/fw_env.config` by default)\n\nThis file should be formatted as described in `from_string/1`.","ref":"UBootEnv.Config.html#from_file/1"},{"type":"function","title":"UBootEnv.Config.from_file!/1","doc":"Raising version of `from_file/1`","ref":"UBootEnv.Config.html#from_file!/1"},{"type":"function","title":"UBootEnv.Config.from_string/1","doc":"Create a UBootEnv.Config from the contents of an `fw_env.config` file\n\nOnly one or two U-Boot environment locations are supported. Each location\nrow has the following format:\n\n```\n \t \t \t[Flash sector size]\t[Number of sectors]\n```","ref":"UBootEnv.Config.html#from_string/1"},{"type":"function","title":"UBootEnv.Config.from_string!/1","doc":"Raising version of `from_string/1`","ref":"UBootEnv.Config.html#from_string!/1"},{"type":"function","title":"UBootEnv.Config.parse_int/1","doc":"Parse an integer\n\nExamples:\n\n```elixir\niex> UBootEnv.Config.parse_int(\"0x12\")\n18\n\niex> UBootEnv.Config.parse_int(\"1234\")\n1234\n```","ref":"UBootEnv.Config.html#parse_int/1"},{"type":"function","title":"UBootEnv.Config.second/1","doc":"Return the second location\n\nThis raises for nonredundant environments.","ref":"UBootEnv.Config.html#second/1"},{"type":"function","title":"UBootEnv.Config.size/1","doc":"Return the environment block size","ref":"UBootEnv.Config.html#size/1"},{"type":"type","title":"UBootEnv.Config.t/0","doc":"","ref":"UBootEnv.Config.html#t:t/0"},{"type":"module","title":"UBootEnv.IO","doc":"Functions for reading and writing raw blocks to storage\n\nThis is the module that handles the low level CRC32 and redundant block\ndetails.","ref":"UBootEnv.IO.html"},{"type":"type","title":"UBootEnv.IO.generation/0","doc":"","ref":"UBootEnv.IO.html#t:generation/0"},{"type":"function","title":"UBootEnv.IO.package/3","doc":"Package up U-Boot environment contents\n\nThe result can be written to where ever the environment block is persisted.","ref":"UBootEnv.IO.html#package/3"},{"type":"function","title":"UBootEnv.IO.read/1","doc":"Read a U-Boot environment block\n\nThis function performs the actual read and in the case of redundant U-Boot\nenvironments, it returns the newer block. It does not decode.","ref":"UBootEnv.IO.html#read/1"},{"type":"function","title":"UBootEnv.IO.unpackage/2","doc":"Unpackage a U-Boot environment block\n\nThis is the opposite of package/3. It will only return successfully\nif the input passes the U-Boot CRC check.","ref":"UBootEnv.IO.html#unpackage/2"},{"type":"function","title":"UBootEnv.IO.write/2","doc":"Write a U-Boot environment block\n\nThis function performs the actual write. In the case of redundant\nU-Boot environments, it writes the block in the right location and\nmarks the generation byte appropriately so that it is used on the next\nread. It does not encode.","ref":"UBootEnv.IO.html#write/2"},{"type":"module","title":"UBootEnv.Location","doc":"Environment block location","ref":"UBootEnv.Location.html"},{"type":"type","title":"UBootEnv.Location.t/0","doc":"","ref":"UBootEnv.Location.html#t:t/0"},{"type":"module","title":"UBootEnv.Serializer","doc":"Encode and decode a U-Boot environment data\n\nThe U-Boot environment data looks like this:\n\n  * `\" = \\0\"` for each key-value pair\n  * `\"\\0\"` an empty key-value pair to terminate the list.\n    This looks like `\"\\0\\0\"` when viewing the file in a hex editor.","ref":"UBootEnv.Serializer.html"},{"type":"function","title":"UBootEnv.Serializer.decode/1","doc":"Decode a U-Boot environment binary data to a map of key/value pairs","ref":"UBootEnv.Serializer.html#decode/1"},{"type":"function","title":"UBootEnv.Serializer.encode/1","doc":"Encode a list of key value pairs into their binary form.","ref":"UBootEnv.Serializer.html#encode/1"},{"type":"extras","title":"UBootEnv","doc":"# UBootEnv\n\n[![Hex version](https://img.shields.io/hexpm/v/uboot_env.svg \"Hex version\")](https://hex.pm/packages/uboot_env)\n[![API docs](https://img.shields.io/hexpm/v/uboot_env.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/uboot_env/UBootEnv.html)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/nerves-project/uboot_env/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/nerves-project/uboot_env/tree/main)\n[![REUSE status](https://api.reuse.software/badge/github.com/nerves-project/uboot_env)](https://api.reuse.software/info/github.com/nerves-project/uboot_env)\n\nThis library lets you read and write [U-Boot](https://www.denx.de/wiki/U-Boot)\nenvironment blocks from Elixir. U-Boot environment blocks are simple key-value\nstores used by the U-Boot bootloader and applications that need to communicate\nwith it. Nerves uses U-Boot environment blocks to store settings related to the\ndevice and running firmware. Nerves uses the format even for boards (like the\nRaspberry Pis) that don't use the U-Boot bootloader.\n\nThis library has the following features:\n\n* Create, read, and write to U-Boot environment blocks in pure Elixir with OTP\n  21 and later\n* Load environment block configurations from `/etc/fw_env.config`\n* Redundant and non-redundant environment block support\n\nThis library does not support U-Boot environment blocks stored in raw NAND Flash\nor big-endian blocks.","ref":"readme.html"},{"type":"extras","title":"Installation - UBootEnv","doc":"Install by adding `uboot_env` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:uboot_env, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Using - UBootEnv","doc":"Here's an example of reading the environment:\n\n```elixir\niex> UBootEnv.read()\n{:ok,\n %{\n   \"fdt_addr\" => \"0x83000000\",\n   \"stdout\" => \"serial\",\n   ...\n }\n}\n```\n\nTo change the environment, update the map returned by `UBootEnv.read/0` and call\n`UBootEnv.write/1`. If you're used to using `fw_setenv`, note that\n`UBootEnv.write/1` writes the map that you give it whereas `fw_setenv` merges\nthe key value pairs with the current environment.\n\n```elixir\niex> {:ok kv} = UBootEnv.read()\niex> new_kv = Map.put(kv, \"hello\", \"world\")\niex> UBootEnv.write(new_kv)\n:ok\n```\n\n`UBootEnv.read/0` and `UBootEnv.write/1` do not perform any locking of the data\nthey write. If you have multiple processes updating the U-Boot environment\nblock, you'll have to synchronize access to it.","ref":"readme.html#using"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v1.0.2 - Changelog","doc":"* Changes\n  * Fix Elixir 1.19 warning\n  * Update licensing and copyright for [REUSE](https://reuse.software)\n    compliance","ref":"changelog.html#v1-0-2"},{"type":"extras","title":"v1.0.1 - Changelog","doc":"* Bug fixes\n  * Sync updates to the environment with the OS to ensure that they're written\n    in case power is removed shortly afterwards. Thanks @parherman.","ref":"changelog.html#v1-0-1"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"This release only changes the version number and updates documentation. No code\nchanges were made.","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"This release adds support for redundant U-Boot environments. It reduces the main\nAPI to `UBootEnv.read/1` and `UBootEnv.write/2`. If you only use those\nfunctions, your code should work without change.\n\n* New features\n  * Redundant U-Boot support","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"This release breaks several APIs so please review your code.\n\nThe first break is that `UBootEnv.encode/2` returns iodata now. In general, the\nreturn value would end up being passed places that supported iodata, but it had\npreviously been spec'd as returning a binary.\n\nThe second break is that `UBootEnv.decode/1` now does the reverse of\n`UBootEnv.encode/2`. It previously was a convenience method, but it was public.\nIt is not expected that many people used the previous function.\n\n* Bug fixes\n  * Reduce the amount of garbage generated when encoding and decoding. A manual\n    call to `:erlang.garbage_collect/1` can free the garbage, but it stays\n    around long enough to make any process calling this library to show up with\n    megabytes more heap used.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Bug fixes\n  * handle trailing whitespace in config\n  * handle 0-length strings in config\n  * handle `:eof` values when reading from env\n\n* Updated dependencies\n  * `ex_doc` ~> 0.20","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}